NextCloud
---------

The following NextCloud settings are available:

.. code-block:: python

    SOCIALACCOUNT_PROVIDERS = {
        'nextcloud': {
            'SERVER': 'https://nextcloud.example.org',
        }
    }


App registration (get your key and secret here)

    https://nextcloud.example.org/settings/admin/security
